<html><head>
<META Http-equiv="Content-Type" Content="text/html;charset=Shift_JIS">
<title><?php print $MOWIKI_TITLE?></title></head>
<body bgcolor="<?php print $MOWIKI_BG?>" text="<?php print $MOWIKI_TEXT?>" link="<?php print $MOWIKI_LINK?>" alink="<?php print $MOWIKI_ALINK?>" vlink="<?php print $MOWIKI_VLINK?>">
<?php print $MOWIKI_TITLE?><br>
<a href="<?php print $_SERVER['PHP_SELF']?>?a=N&r=<?php print $MOWIKI_RAND?>" accesskey="1">VK</a>
<?php if ($gIn['a'] != 'M') { ?>
<?php } ?>
<a href="<?php print $_SERVER['PHP_SELF']?>?r=<?php print $MOWIKI_RAND?>" accesskey="2">gbv</a> 
<a href="<?php print $_SERVER['PHP_SELF']?>?a=L&r=<?php print $MOWIKI_RAND?>" accesskey="3">Xg</a> 
<hr color="<?php print $MOWIKI_HR_COLOR?>">
<?php print $gOut['body']?>
<hr color="<?php print $MOWIKI_HR_COLOR?>">
<?php if ($gOut['edit'] == 1) { ?>
<a href="<?php print $_SERVER['PHP_SELF']?>?a=M&title=<?php print $gIn['title']?>" accesskey="0">̃y[WҏW</a><br>
<?php } ?>
<br>
Admin: <?php print $MOWIKI_ADMIN?><br>
<a href="http://sourceforge.jp/"><img src="http://sourceforge.jp/sflogo.php?group_id=1420" width="96" height="31" border="0" alt="SourceForge.jp"></a>
</body></html>